@@ -1,5 +1,5 @@
 package Class::props ;
-$VERSION = 2.12 ;
+$VERSION = 2.2 ;
 use 5.006_001 ;
 use strict ;
   
@@ -47,13 +47,16 @@ use strict ;
       ; *{$pkg.'::'.$n}
         = sub : lvalue
            { (@_ > 2) && croak qq(Too many arguments for "$n" property, died)
-           ;  my $scalar = $tool =~ /^Class/
-                           ? $gr
-                             ? \${(ref $_[0]||$_[0]).'::'.$gr}{$n}
-                             : \${(ref $_[0]||$_[0]).'::'.$n}
-                           : $gr
-                             ? \$_[0]{$gr}{$n}
-                             : \$_[0]{$n}
+           ; my $scalar
+             = $tool =~ /^Class/   ? $gr
+                                     ? \${(ref $_[0]||$_[0]).'::'.$gr}{$n}
+                                     : \${(ref $_[0]||$_[0]).'::'.$n}
+             : $tool =~ /^Package/ ? $gr
+                                     ? \${$pkg.'::'.$gr}{$n}
+                                     : \${$pkg.'::'.$n}
+             : $gr
+               ? \$_[0]{$gr}{$n}
+               : \$_[0]{$n}
            ; my $Tscalar
            ; if ( $to_tie )
               { tie $$Tscalar
@@ -153,9 +156,9 @@ __END__
 
 Class::props - Pragma to implement lvalue accessors with options
 
-=head1 VERSION 2.12
+=head1 VERSION 2.2
 
-Included in OOTools 2.12 distribution.
+Included in OOTools 2.2 distribution.
 
 The latest versions changes are reported in the F<Changes> file in this distribution.
 
@@ -163,6 +166,14 @@ The distribution includes:
 
 =over
 
+=item Package::props
+
+Pragma to implement lvalue accessors with options
+
+=item * Package::groups
+
+Pragma to implement groups of properties accessors with options
+
 =item * Class::constr
 
 Pragma to implement constructor methods
@@ -179,6 +190,10 @@ Pragma to implement groups of properties accessors with options
 
 Delayed checking of object failure
 
+=item * Class::Util
+
+Class utility functions
+
 =item * Object::props
 
 Pragma to implement lvalue accessors with options
@@ -187,10 +202,6 @@ Pragma to implement lvalue accessors with options
 
 Pragma to implement groups of properties accessors with options
 
-=item * Class::Util
-
-Class utility functions
-
 =back
 
 =head1 INSTALLATION
@@ -290,11 +301,46 @@ The accessor method creates a scalar in the class that implements it (e.g. $Clas
 
 B<IMPORTANT NOTE>: Since the version 1.7 the options don't work if you access the scalar without using the accessor, so you can access the value directly when you need to bypass the options.
 
-=head2 Class properties vs Object properties
+=head2 Package, Class or Object properties?
 
-The main difference between C<Object::props> and C<Class::props> is that the first pragma creates instance properties related with the object and stored in $object->{property}, while the second pragma creates class properties related with the class and stored in $Class::property.
+The main difference between  C<Packages::props>, C<Object::props> and C<Class::props> is the underlaying scalar that holds the value of the property.
 
-A Class property is accessible either through the class or through all the objects of that class, while an object property is accessible only through the object that set it.
+Look at this example:
+
+   package BaseClass;
+   use Object::props  'an_object_prop';
+   use Class::props   'a_class_prop';
+   use Package::props 'a_package_prop';
+   
+   use Class::constr;
+   
+   package SubClass;
+   our @ISA = 'BaseClass';
+   
+   package main;
+   $obj = SubClass->new;
+   
+   # object
+   $obj->an_object_prop;        # accessor callable through the object
+   $obj->{an_object_prop};      # underlaying scalar in object $obj
+   
+   # class
+   $obj->a_class_prop;          # accessor callable through the object
+   ref($obj)->a_class_prop;     # accessor callable through the object class
+   $SubClass::a_class_prop;     # underlaying scalar in class 'SubClass'
+   
+   # package
+   $obj->a_package_prop;        # accessor callable through the object
+   ref($obj)->a_package_prop;   # accessor callable through the object class
+                                # accessible through @ISA
+   BaseClass->a_package_prop;   # accessor callable through the package
+   $BaseClass::a_package_prop;  # underlaying scalar in package 'BaseClass'
+
+The object property is stored into the object itself, a class property is stored in a global scalar in the object class itself, while a package property is sotored in the package that implements it.
+
+Different underlaying scalars are suitable for different usages depending on the need to access them and to inherit the defaults.
+
+=head2 Example
 
    package MyClass;
    use Class::constr ;
@@ -330,9 +376,7 @@ A Class property is accessible either through the class or through all the objec
    print $object1->class_prop2 ; # would print 200
    print $object2->class_prop2 ; # would print 200
 
-=head2 Examples
-
-If you want to see some working example of this module, take a look at the source of my other distributions.
+B<Note>: If you want to see some working example of this module, take a look at the source of my other distributions.
 
 =head1 OPTIONS
 
